/**
 * @fileoverview You must require _ on all lodash imports
 * @author George Weiler
 */
"use strict";

//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

var rule = require("../../../lib/rules/require-underscore-lodash-import"),
  RuleTester = require("eslint").RuleTester;
RuleTester.setDefaultConfig({
  parserOptions: {
    sourceType: "module",
    ecmaVersion: 6,
    ecmaFeatures: {
      jsx: true,
    },
  },
});
const ERROR_MSG = "Lodash imports must include '_'";

var ruleTester = new RuleTester();
ruleTester.run("require-underscore-lodash-import", rule, {
  valid: [
    {
      code: `import _map from "lodash/map;"`,
    },
    {
        code: `import _uniq from "lodash/uniq;"`,
    },
  ],
  invalid: [
    {
      code: `import map from "lodash/map";`,
      type: "ImportDefaultSpecifier",
      errors: [
        {
          message: ERROR_MSG,
        },
      ],
    },
    {
        code: `import uniq from "lodash/uniq";`,
        type: "ImportDefaultSpecifier",
        errors: [
          {
            message: ERROR_MSG,
          },
        ],
      },
  ],
});
